//
//  HoppingViewController.m
//  AsReader 6Combo
//
//  Created by Robin on 2016. 9. 8..
//
//

#import "HoppingViewController.h"
#import "Utils.h"
#import <AsReaderDockSDK/AsReaderDockSDK.h>

@interface HoppingViewController ()<AsReaderRFIDDeviceDelegate, AsReaderDeviceDelegate>

@property (weak, nonatomic) IBOutlet UILabel *labelInfo;
@property (weak, nonatomic) IBOutlet UISwitch *swOnOff;
@property (weak, nonatomic) IBOutlet UISwitch *swMode;
@property (weak, nonatomic) IBOutlet UIButton *btnStep2;
@end

@implementation HoppingViewController

#define DEVICE_ASX_300R 302

#pragma mark - Lifecycle
//----------------------------------------------------------------
- (void)viewDidLoad
{
    [super viewDidLoad];
    
    [self getInfo];
    // Do any additional setup after loading the view.
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [AsReaderRFIDDevice sharedInstance].delegateDevice = self;
    [AsReaderRFIDDevice sharedInstance].delegateRFID = self;
    
    [self performSelector:@selector(onTickGetFHInfo) withObject:nil afterDelay:0.5f];
    
    if([[AsReaderInfo sharedInstance].deviceModelNumber isEqualToString:@"ASX-300R"]==YES ) {
        [self.swMode setHidden:YES];
        [self.btnStep2 setHidden:YES];
    } else {
        [self.swMode setHidden:NO];
        [self.btnStep2 setHidden:NO];
    }
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [AsReaderRFIDDevice sharedInstance].delegateDevice = nil;
    [AsReaderRFIDDevice sharedInstance].delegateRFID = nil;
}

#pragma mark - Private method
//----------------------------------------------------------------
- (void)getInfo
{
    dispatch_async(dispatch_get_main_queue(), ^{
        AsReaderInfo *info = [AsReaderInfo sharedInstance];
        NSMutableString *strInfo = [[NSMutableString alloc]init];
                       
        if(info.rfidFrequencyHopping>info.rfidListenBeforeTalk){
            [strInfo appendString:@"FH ON/OFF : ON"];
            [self.swOnOff setOn:YES];
            
        } else {
            [strInfo appendString:@"FH ON/OFF : OFF"];
            [self.swOnOff setOn:NO];
        }
                       
        [strInfo appendString:[NSString stringWithFormat:@"\n %@:%d",@"On Time : ",info.rfidOnTime]];
        [strInfo appendString:[NSString stringWithFormat:@"\n %@:%d",@"Off Time : ",info.rfidOffTime]];
        [strInfo appendString:[NSString stringWithFormat:@"\n %@:%d",@"CST : ",info.carrierSenseTime]];
        [strInfo appendString:[NSString stringWithFormat:@"\n %@:%d",@"FH Val : ",info.rfidFrequencyHopping]];
        [strInfo appendString:[NSString stringWithFormat:@"\n %@:%d",@"RFL : ",info.targetRFPowerLevel]];
        [strInfo appendString:[NSString stringWithFormat:@"\n %@:%d",@"LBT : ",info.rfidListenBeforeTalk]];
        [strInfo appendString:[NSString stringWithFormat:@"\n %@:%d",@"CW  : ",info.rfidContinuousWave]];
        
        if( info.isSmartHopping==YES ){
            [strInfo appendString:@" FhMode : SMART "];
            [self.swMode setOn:YES];
        } else {
            [strInfo appendString:@" FhMode : NORMAL "];
            [self.swMode setOn:NO];
        }
        [self.labelInfo setText:strInfo];
    });
}

- (void)showAlert:(NSString *)strMsg
{
    [Utils showAlert:@"" message:strMsg view:self];
    // TODO: AlertViewControllerに変更する。
//    dispatch_async(dispatch_get_main_queue(), ^{
//        [self.alert setMessage:strMsg];
//        [self.alert show];
//    });
}

- (void)onTickGetFHInfo
{
    [[AsReaderRFIDDevice sharedInstance] getFrequencyHoppingMode];
}

#pragma mark - IBAction
//----------------------------------------------------------------
- (IBAction)btnSelectHoppingmode:(id)sender
{
    UISwitch *sw = (UISwitch*)sender;
    if(sw.isOn) {
        [self showAlert:@"Selected Smart Mode   => push Step2"];
    } else {
        [self showAlert:@"Selected Normal Mode  => push Step2"];
    }
}

- (IBAction)actionSwitchHoppingOnOff:(UISwitch *)sender
{
    if(sender.isOn == YES) {
        // Hopping ON
        [[AsReaderRFIDDevice sharedInstance] setHoppingOnOff:YES];
    } else {
        // Hopping OFF
        [[AsReaderRFIDDevice sharedInstance] setHoppingOnOff:NO];
    }
}

//reflesh Info
- (IBAction)btnRefleshInfo:(id)sender
{
    [[AsReaderRFIDDevice sharedInstance] getFrequencyHoppingMode];
    [[AsReaderRFIDDevice sharedInstance] getFhLbtParameter];
}

- (IBAction)btnStep1:(id)sender
{
    [[AsReaderRFIDDevice sharedInstance] setOptimumFrequencyHoppingTable];
}

- (IBAction)btnStep2:(id)sender
{
    BOOL bValue = self.swMode.on;
    [[AsReaderRFIDDevice sharedInstance] setSmartHoppingOnOff:bValue];
}

#pragma mark - AsReaderRFIDDeviceDelegate
//----------------------------------------------------------------
//Get Info
- (void)fhLbtReceived:(NSData *)fhLb;
{
    [self getInfo];
    [self showAlert:@"Refreshed Info"];
}

- (void)didSetFhLbt:(int)status
{
    [self showAlert:@"Set FH/LBT Param"];
}

- (void)resGetFHmode
{
    dispatch_async(dispatch_get_main_queue(), ^{
        [self getInfo];
    });
}

- (void)didSetFHmodeChanged
{
    [self showAlert:@"didSetFhModeChange"];
}

- (void)didSetOptiFreqHPTable:(int)status
{
    if(status == 0x00) {
        [self showAlert:@"Wait!! Start OptiMum Freq Start"];
    }
    
    if(status == 0x01) {
        [self showAlert:@"Finish  OptiMum Freq"];
    }
}

- (void)errorReceived:(NSData *)errorCode
{
    Byte *b = (Byte *)[errorCode bytes];
    dispatch_async(dispatch_get_main_queue(), ^{
       switch (b[1]){
           case 0xE4:
           case 0xE6:
           case 0xD2: {
               [Utils showAlert:@"Error" message:@"The retrun loss of antenna is too large to optimize channel." view:self];
               break;
           }
           default:
               break;
       }
   });
}

- (void)plugged:(BOOL)plug {
    
}

- (void)readerConnected:(int)status {
    
}
@end
